@@ -10,6 +10,7 @@ from fastapi.staticfiles import StaticFiles
 
 
 LOG_LEVEL = logging.getLevelName(os.environ.get("LOG_LEVEL", "INFO"))
+PORT = int(os.environ.get("NETCONFIG_PORT", "8039"))
 JSON_LOGS = True if os.environ.get("JSON_LOGS", "0") == "1" else False
 
 
@@ -69,7 +70,7 @@ def run_server():
         Config(
             "ebs.linuxnode.netconfig.server:app",
             host="0.0.0.0",
-            port=8039,
+            port=PORT,
             log_level=LOG_LEVEL,
         ),
     )
